ApiResponseRecord class

Constructors

ApiResponseRecord({required int id, required String endpoint, required int statusCode, required String responseData, required ParsingStatus parsingStatus, required ApiStatus apiStatus, String? parsingError, String? stackTrace, String? modelStructure, required DateTime timestamp})
ApiResponseRecord.fromMap(Map<String, dynamic> map)
factory

Properties

apiStatus ApiStatus
final
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
modelStructure String?
final
parsingError String?
final
parsingStatus ParsingStatus
final
responseData String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
statusCode int
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited