ApiResponseTracker class

Constructors

ApiResponseTracker()
factory

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFailedParsingResponses() Future<List<ApiResponseRecord>>
getLatestResponseForEndpoint(String endpoint) Future<ApiResponseRecord?>
getLatestSuccessfulResponseForEndpoint(String endpoint) Future<ApiResponseRecord?>
getResponsesForEndpoint(String endpoint) Future<List<ApiResponseRecord>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
storeApiResponse({required String endpoint, required int statusCode, required dynamic responseData, required ParsingStatus parsingStatus, ApiStatus apiStatus = ApiStatus.success, String? parsingError, String? stackTrace, String? modelStructure}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited