JsonDiffResult class

Constructors

JsonDiffResult({required Map<String, dynamic> additions, required Map<String, dynamic> removals, required Map<String, dynamic> changes, required List<String> pathsWithDifferences})

Properties

additions Map<String, dynamic>
final
changes Map<String, dynamic>
final
hasDifferences bool
no setter
hashCode int
The hash code for this object.
no setterinherited
pathsWithDifferences List<String>
final
removals Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited