TypeMismatch class

Constructors

TypeMismatch({required String fieldPath, required String expectedType, required String actualType, bool isNullabilityIssue = false, bool isMissingField = false})

Properties

actualType String
final
expectedType String
final
fieldPath String
final
hashCode int
The hash code for this object.
no setterinherited
isMissingField bool
final
isNullabilityIssue bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited